@@ -23,7 +23,7 @@ class LimitRange(NamespacedResource):
 
     def to_dict(self) -> None:
         super().to_dict()
-        if not self.yaml_file:
+        if not self.kind_dict and not self.yaml_file:
             if not self.limits:
                 raise MissingRequiredArgumentError(argument="limits")
 
